@@ -640,6 +640,58 @@ let multiDomainFirstPartiesArray = [
   ],
   ["bbc.co.uk", "bbc.com", "bbci.co.uk"],
   ["belkin.com", "seedonk.com"],
+  [
+    "bellmedia.ca",
+
+    "9c9media.ca",
+    "9c9media.com",
+    "animalplanet.ca",
+    "bardown.com",
+    "bnnbloomberg.ca",
+    "bnn.ca",
+    "bravo.ca",
+    "canald.com",
+    "canalvie.com",
+    "cinepop.ca",
+    "cmdy.ca",
+    "cookieless.ca",
+    "cp24.com",
+    "crave.ca",
+    "crave.com",
+    "cravetv.ca",
+    "ctv.ca",
+    "ctvdigital.net",
+    "ctvnews.ca",
+    "discovery.ca",
+    "discoveryvelocity.ca",
+    "envedette.ca",
+    "etalk.ca",
+    "fraichementpresse.ca",
+    "investigationdiscovery.ca",
+    "investigationtele.com",
+    "lookdujour.ca",
+    "marilyn.ca",
+    "mtv.ca",
+    "much.ca",
+    "much.com",
+    "muchmusic.com",
+    "muramur.ca",
+    "rds.ca",
+    "sciencechannel.ca",
+    "sego-cdn.com",
+    "space.ca",
+    "superecran.com",
+    "superecrango.com",
+    "sympatico.ca",
+    "thecomedynetwork.ca",
+    "theloop.ca",
+    "thesocial.ca",
+    "tmngo.ca",
+    "tsn.ca",
+    "voyagevoyage.ca",
+    "vrak.tv",
+    "ztele.com",
+  ],
   ["bhphotovideo.com", "bandh.com", "bhphoto.com", "bnh.com"],
   ["bilibili.com", "acgvideo.com", "biliapi.net", "biliapi.com", "biligame.com", "hdslb.com"],
   ["binance.com", "binance.cloud", "binance.vision", "bnbstatic.com"],
@@ -660,6 +712,35 @@ let multiDomainFirstPartiesArray = [
     "romper.com",
     "thezoereport.com",
   ],
+  [
+    "canada.ca",
+
+    "ceaa-acee.gc.ca",
+    "collectionscanada.gc.ca",
+    "cra-arc.gc.ca",
+    "dfo-mpo.gc.ca",
+    "ec.gc.ca",
+    "esdc.gc.ca",
+    "fcac-acfc.gc.ca",
+    "hrdc-drhc.gc.ca",
+    "ic.gc.ca",
+    "jobbank.gc.ca",
+    "labour.gc.ca",
+    "nrcan.gc.ca",
+    "sac-isc.gc.ca",
+    "servicecanada.gc.ca",
+    "services.gc.ca",
+    "statcan.gc.ca",
+    "tbs-sct.gc.ca",
+    "tc.gc.ca",
+    "tpsgc-pwgsc.gc.ca",
+    "weather.gc.ca",
+
+    "archives.ca",
+    "canlearn.ca",
+    "gcsurplus.ca",
+    "letstalktransportation.ca",
+  ],
   [
     "canalplus.com",
 
@@ -734,6 +815,16 @@ let multiDomainFirstPartiesArray = [
   ["century21.com", "21online.com"],
   ["chart.io", "chartio.com"],
   ["chaturbate.com", "highwebmedia.com"],
+  [
+    "cisco.com",
+
+    "ciscolive.com",
+    "duo.com",
+    "netacad.com",
+    "webex.com",
+
+    "static-cisco.com",
+  ],
   ["cms.gov", "medicare.gov", "mymedicare.gov"],
   ["codepen.io", "cdpn.io"],
   ["concur.com", "concursolutions.com"],
@@ -747,6 +838,28 @@ let multiDomainFirstPartiesArray = [
     "hbw.com",
     "macaulaylibrary.org",
   ],
+  [
+    "condenast.com",
+
+    "architecturaldigest.com",
+    "arstechnica.com",
+    "bonappetit.com",
+    "cntraveler.com",
+    "epicurious.com",
+    "glamour.com",
+    "gq.com",
+    "lennyletter.com",
+    "newyorker.com",
+    "pitchfork.com",
+    "self.com",
+    "teenvogue.com",
+    "them.us",
+    "vanityfair.com",
+    "vogue.com",
+    "wired.com",
+
+    "condenastdigital.com",
+  ],
   ["cox.com", "cox.net"],
   ["cricketwireless.com", "aiowireless.com"],
   ["ctrip.com", "c-ctrip.com", "trip.com"],
@@ -887,6 +1000,17 @@ let multiDomainFirstPartiesArray = [
   ["discord.com", "discordapp.com", "discordapp.net"],
   ["discover.com", "discovercard.com"],
   ["disqus.com", "disquscdn.com"],
+  [
+    "dmgmedia.co.uk",
+
+    "dailymail.co.uk",
+    "inews.co.uk",
+    "mailonsunday.co.uk",
+    "metro.co.uk",
+    "thisismoney.co.uk",
+
+    "dmgmediaprivacy.co.uk",
+  ],
   [
     "dpgmediagroup.com",
 
@@ -902,6 +1026,7 @@ let multiDomainFirstPartiesArray = [
     "demorgen.be",
     "destentor.nl",
     "dpgmedia.be",
+    "dpgmedia.nl",
     "ed.nl",
     "gelderlander.nl",
     "hln.be",
@@ -917,6 +1042,9 @@ let multiDomainFirstPartiesArray = [
     "trouw.nl",
     "tubantia.nl",
     "volkskrant.nl",
+    "vtm.be",
+
+    "dpgmedia.net",
   ],
   ["dropbox.com", "dropboxstatic.com", "dropboxusercontent.com", "getdropbox.com"],
   ["d.rip", "kickstarter.com"],
@@ -1041,6 +1169,44 @@ let multiDomainFirstPartiesArray = [
     "alamo-np.ie",
   ],
   ["epicgames.com", "unrealengine.com"],
+  [
+    "eventbrite.com",
+
+    "eventbrite.at",
+    "eventbrite.be",
+    "eventbrite.ca",
+    "eventbrite.ch",
+    "eventbrite.cl",
+    "eventbrite.co",
+    "eventbrite.com.ar",
+    "eventbrite.com.au",
+    "eventbrite.com.br",
+    "eventbrite.com.mx",
+    "eventbrite.com.ng",
+    "eventbrite.com.pe",
+    "eventbrite.co.nz",
+    "eventbrite.co.uk",
+    "eventbrite.co.za",
+    "eventbrite.de",
+    "eventbrite.dk",
+    "eventbrite.es",
+    "eventbrite.fi",
+    "eventbrite.fr",
+    "eventbrite.hk",
+    "eventbrite.ie",
+    "eventbrite.in",
+    "eventbrite.it",
+    "eventbrite.my",
+    "eventbrite.nl",
+    "eventbrite.ph",
+    "eventbrite.pt",
+    "eventbrite.se",
+    "eventbrite.sg",
+
+    "evbstatic.com",
+    "evbuc.com",
+    "eventbriteapi.com",
+  ],
   [
     "expedia.com",
 
@@ -1311,7 +1477,6 @@ let multiDomainFirstPartiesArray = [
     "thinkstockphotos.com",
     "thinkstockphotos.ca",
   ],
-  ["github.com", "githubapp.com"],
   ["gitlab.com", "gitlab-static.net"],
   [
     "gizmodo.com",
@@ -1556,6 +1721,7 @@ let multiDomainFirstPartiesArray = [
     "www.googleapis.com",
 
     "nest.com",
+    "codingcompetitions.withgoogle.com",
     "nestpowerproject.withgoogle.com",
   ],
   ["www.gov.uk", "cabinet-office.gov.uk", "publishing.service.gov.uk"],
@@ -1854,6 +2020,37 @@ let multiDomainFirstPartiesArray = [
     "immobilienscout24.de",
     "static-immobilienscout24.de",
   ],
+  [
+    "indeed.com",
+
+    "indeed.ae",
+    "indeed.ca",
+    "indeed.ch",
+    "indeed.cl",
+    "indeed.co.in",
+    "indeed.com.au",
+    "indeed.com.br",
+    "indeed.com.co",
+    "indeed.com.mx",
+    "indeed.com.my",
+    "indeed.com.pe",
+    "indeed.com.ph",
+    "indeed.com.pk",
+    "indeed.com.sg",
+    "indeed.co.uk",
+    "indeed.co.ve",
+    "indeed.co.za",
+    "indeed.de",
+    "indeed.es",
+    "indeed.fi",
+    "indeed.fr",
+    "indeed.hk",
+    "indeed.ie",
+    "indeed.jp",
+    "indeed.lu",
+    "indeed.nl",
+    "indeed.pt",
+  ],
   ["independent.co.uk", "indy100.com"],
   [
     "iu.edu",
@@ -1897,8 +2094,20 @@ let multiDomainFirstPartiesArray = [
     "yiyaojd.com",
     "yizhitou.com",
   ],
+  [
+    "jetbrains.com",
+
+    "datalore.io",
+    "intellij.net",
+    "jetbrains.dev",
+    "kotlinconf.com",
+    "kotlinlang.org",
+    "ktor.io",
+    "talkingkotlin.com",
+  ],
   ["jpmorganchase.com", "jpmorgan.com", "chase.com"],
   ["jobware.de", "jobware.com", "jobware.net"],
+  ["jotform.com", "jotfor.ms"],
   [
     "kayak.com",
 
@@ -2315,6 +2524,19 @@ let multiDomainFirstPartiesArray = [
     "xboxlive.com",
     "yammer.com",
     "yammerusercontent.com",
+
+    "github.com",
+    "githubapp.com",
+    "githubassets.com",
+    "github.dev",
+
+    "avatars0.githubusercontent.com",
+    "avatars1.githubusercontent.com",
+    "avatars2.githubusercontent.com",
+    "avatars3.githubusercontent.com",
+    "camo.githubusercontent.com",
+    "cloud.githubusercontent.com",
+    "raw.githubusercontent.com",
   ],
   ["mobilism.org.in", "mobilism.org"],
   ["morganstanley.com", "morganstanleyclientserv.com", "stockplanconnect.com", "ms.com"],
@@ -2421,8 +2643,36 @@ let multiDomainFirstPartiesArray = [
   ["mymerrill.com", "ml.com", "merrilledge.com"],
   ["mynortonaccount.com", "norton.com"],
   ["mysmartedu.com", "mysmartabc.com"],
-  ["mysql.com", "oracle.com"],
   ["myuv.com", "uvvu.com"],
+  [
+    "naver.com",
+
+    "grafolio.com",
+    "plug.game",
+    "vlive.tv",
+    "webtoons.com",
+
+    "naver.net",
+    "pstatic.net",
+
+    "blog.jp",
+    "blogos.com",
+    "doorblog.jp",
+    "ldblog.jp",
+    "linecorp.com",
+    "line.me",
+    "livedoor.com",
+    "livedoor.jp",
+
+    "blogcms.jp",
+    "blogimg.jp",
+    "blogsys.jp",
+    "line-apps.com",
+    "line.biz",
+    "line-scdn.net",
+    "livedoor.net",
+    "naver.jp",
+  ],
   [
     "nbcnews.com",
 
@@ -2583,6 +2833,7 @@ let multiDomainFirstPartiesArray = [
     "nvidia.at",
     "nvidia.be",
     "nvidia.ch",
+    "nvidia.cn",
     "nvidia.co.at",
     "nvidia.co.in",
     "nvidia.co.jp",
@@ -2617,12 +2868,28 @@ let multiDomainFirstPartiesArray = [
     "nvidia.se",
     "nvidia.tw",
 
+    "nvidiagrid.net",
+    "nvidia.partners",
+
     "geforce.com",
+    "geforcenow.com",
+    "gputechconf.com",
+
     "geforce.cn",
+    "geforce.com.tw",
     "geforce.co.uk",
   ],
   ["onlineatnsb.com", "norwaysavingsbank.com"],
   ["openstreetmap.org", "osmfoundation.org"],
+  [
+    "oracle.com",
+
+    "ateam-oracle.com",
+    "java.com",
+    "mysql.com",
+
+    "oracleimg.com",
+  ],
   ["orange.fr", "sosh.fr", "woopic.com"],
   [
     "osf.io",
@@ -2792,6 +3059,7 @@ let multiDomainFirstPartiesArray = [
     "the-voice-of-germany.at",
     "the-voice-of-germany.ch",
     "the-voice-of-germany.de",
+    "zappn.tv",
 
     "p7s1.io",
   ],
@@ -3178,6 +3446,7 @@ let multiDomainFirstPartiesArray = [
   ["squareup.com", "cash.app", "mkt.com", "squarecdn.com"],
   ["steampowered.com", "steamstatic.com", "steamcommunity.com"],
   ["suning.com", "suning.cn", "hksuning.com"],
+  ["target.com", "targetimg1.com"],
   ["techdata.com", "techdata.ch"],
   ["telegram.org", "telegram.me", "t.me"],
   ["telekom.com", "t-online.de"],
@@ -3740,7 +4009,7 @@ let multiDomainFirstPartiesArray = [
     "wpimg.pl",
   ],
   ["wpcu.coop", "wpcuonline.com"],
-  ["wsj.com", "wsj.net", "barrons.com", "dowjones.com", "marketwatch.com"],
+  ["wsj.com", "wsj.net", "barrons.com", "dowjones.com", "dowjoneson.com", "mansionglobal.com", "marketwatch.com"],
   ["xda-developers.com", "xda-cdn.com"],
   ["xfinity.com", "comcast.net", "comcast.com"],
   ["xhamster.com", "xhcdn.com"],
@@ -3779,6 +4048,24 @@ let multiDomainFirstPartiesArray = [
     "yandex.uz",
     "ya.ru",
   ],
+  ["yoox.com", "mrporter.com", "theoutnet.com", "yoox.it"],
+  [
+    "sph.com.sg",
+
+    "sphdigital.com",
+
+    "beritaharian.sg",
+    "businesstimes.com.sg",
+    "shinmin.sg",
+    "straitstimes.com",
+    "tabla.com.sg",
+    "tamilmurasu.com.sg",
+    "tnp.sg",
+    "wanbao.com.sg",
+    "zaobao.com",
+    "zaobao.com.sg",
+    "zaobao.sg"
+  ],
   ["zendesk.com", "zopim.com"],
   ["zhaopin.com", "zhaopin.cn"],
   ["zillow.com", "zillowstatic.com", "zillowcloud.com", "zg-api.com"],
