@@ -16,9 +16,10 @@
  */
 
 window.OPTIONS_INITIALIZED = false;
+window.SLIDERS_DONE = false;
 
 const TOOLTIP_CONF = {
-  maxWidth: 200
+  maxWidth: 400
 };
 const USER_DATA_EXPORT_KEYS = ["action_map", "snitch_map", "settings_map"];
 
@@ -49,7 +50,7 @@ function loadOptions() {
   $('#resetData').on("click", resetData);
   $('#removeAllData').on("click", removeAllData);
 
-  if (OPTIONS_DATA.showTrackingDomains) {
+  if (OPTIONS_DATA.settings.showTrackingDomains) {
     $('#tracking-domains-overlay').hide();
   } else {
     $('#blockedResourcesContainer').hide();
@@ -106,49 +107,106 @@ function loadOptions() {
   $("#resetData").button("option", "icons", {primary: "ui-icon-arrowrefresh-1-w"});
   $("#removeAllData").button("option", "icons", {primary: "ui-icon-closethick"});
   $("#show_counter_checkbox").on("click", updateShowCounter);
-  $("#show_counter_checkbox").prop("checked", OPTIONS_DATA.showCounter);
+  $("#show_counter_checkbox").prop("checked", OPTIONS_DATA.settings.showCounter);
   $("#replace-widgets-checkbox")
     .on("click", updateWidgetReplacement)
     .prop("checked", OPTIONS_DATA.isWidgetReplacementEnabled);
   $("#enable_dnt_checkbox").on("click", updateDNTCheckboxClicked);
-  $("#enable_dnt_checkbox").prop("checked", OPTIONS_DATA.isDNTSignalEnabled);
+  $("#enable_dnt_checkbox").prop("checked", OPTIONS_DATA.settings.sendDNTSignal);
   $("#check_dnt_policy_checkbox").on("click", updateCheckingDNTPolicy);
-  $("#check_dnt_policy_checkbox").prop("checked", OPTIONS_DATA.isCheckingDNTPolicyEnabled).prop("disabled", !OPTIONS_DATA.isDNTSignalEnabled);
+  $("#check_dnt_policy_checkbox").prop("checked", OPTIONS_DATA.settings.checkForDNTPolicy).prop("disabled", !OPTIONS_DATA.settings.sendDNTSignal);
+
+  // only show the alternateErrorPagesEnabled override if browser supports it
+  if (chrome.privacy && chrome.privacy.services && chrome.privacy.services.alternateErrorPagesEnabled) {
+    $("#privacy-settings-header").show();
+    $("#disable-google-nav-error-service").show();
+    $('#disable-google-nav-error-service-checkbox')
+      .prop("checked", OPTIONS_DATA.settings.disableGoogleNavErrorService)
+      .on("click", overrideAlternateErrorPagesSetting);
+  }
+
+  // only show the hyperlinkAuditingEnabled override if browser supports it
+  if (chrome.privacy && chrome.privacy.websites && chrome.privacy.websites.hyperlinkAuditingEnabled) {
+    $("#privacy-settings-header").show();
+    $("#disable-hyperlink-auditing").show();
+    $("#disable-hyperlink-auditing-checkbox")
+      .prop("checked", OPTIONS_DATA.settings.disableHyperlinkAuditing)
+      .on("click", overrideHyperlinkAuditingSetting);
+  }
 
   if (OPTIONS_DATA.webRTCAvailable) {
+    $("#webRTCToggle").show();
     $("#toggle_webrtc_mode").on("click", toggleWebRTCIPProtection);
 
     chrome.privacy.network.webRTCIPHandlingPolicy.get({}, result => {
-      // only enable the checkbox if pb can control webrtc ip leak protection
-      if (result.levelOfControl.endsWith("_by_this_extension")) {
-        $("#toggle_webrtc_mode").attr("disabled", false);
-      }
-
       // auto check the option box if ip leak is already protected at diff levels, via pb or another extension
       if (result.value == "default_public_interface_only" || result.value == "disable_non_proxied_udp") {
         $("#toggle_webrtc_mode").prop("checked", true);
       }
     });
+  }
 
-  } else {
-    // Hide WebRTC-related settings for non-supporting browsers
-    $("#webRTCToggle").hide();
-    $("#webrtc-warning").hide();
+  $('#local-learning-checkbox')
+    .prop("checked", OPTIONS_DATA.settings.learnLocally)
+    .on("click", (event) => {
+      const enabled = $(event.currentTarget).prop("checked");
+      chrome.runtime.sendMessage({
+        type: "updateSettings",
+        data: {
+          learnLocally: enabled
+        }
+      }, function () {
+        $("#learn-in-incognito-checkbox")
+          .prop("disabled", (enabled ? false : "disabled"))
+          .prop("checked", (enabled ? OPTIONS_DATA.settings.learnInIncognito : false));
+        $("#show-nontracking-domains-checkbox")
+          .prop("disabled", (enabled ? false : "disabled"))
+          .prop("checked", (enabled ? OPTIONS_DATA.settings.showNonTrackingDomains : false));
+
+        $("#learning-setting-divs").slideToggle(enabled);
+        $("#not-yet-blocked-filter").toggle(enabled);
+      });
+    });
+  if (OPTIONS_DATA.settings.learnLocally) {
+    $("#learning-setting-divs").show();
+    $("#not-yet-blocked-filter").show();
   }
 
   $("#learn-in-incognito-checkbox")
-    .on("click", updateLearnInIncognito)
-    .prop("checked", OPTIONS_DATA.isLearnInIncognitoEnabled);
-
-  $('#show-nontracking-domains-checkbox')
+    .prop("disabled", OPTIONS_DATA.settings.learnLocally ? false : "disabled")
+    .prop("checked", (
+      OPTIONS_DATA.settings.learnLocally ?
+        OPTIONS_DATA.settings.learnInIncognito : false
+    ))
     .on("click", (event) => {
-      let showNonTrackingDomains = $(event.currentTarget).prop("checked");
+      const enabled = $(event.currentTarget).prop("checked");
       chrome.runtime.sendMessage({
         type: "updateSettings",
-        data: { showNonTrackingDomains }
+        data: {
+          learnInIncognito: enabled
+        }
+      }, function () {
+        OPTIONS_DATA.settings.learnInIncognito = enabled;
       });
-    })
-    .prop("checked", OPTIONS_DATA.showNonTrackingDomains);
+    });
+
+  $('#show-nontracking-domains-checkbox')
+    .prop("disabled", OPTIONS_DATA.settings.learnLocally ? false : "disabled")
+    .prop("checked", (
+      OPTIONS_DATA.settings.learnLocally ?
+        OPTIONS_DATA.settings.showNonTrackingDomains : false
+    ))
+    .on("click", (event) => {
+      const enabled = $(event.currentTarget).prop("checked");
+      chrome.runtime.sendMessage({
+        type: "updateSettings",
+        data: {
+          showNonTrackingDomains: enabled
+        }
+      }, function () {
+        OPTIONS_DATA.settings.showNonTrackingDomains = enabled;
+      });
+    });
 
   const widgetSelector = $("#hide-widgets-select");
   widgetSelector.prop("disabled",
@@ -165,7 +223,7 @@ function loadOptions() {
   // Initialize Select2 and populate options
   widgetSelector.select2();
   OPTIONS_DATA.widgets.forEach(function (key) {
-    const isSelected = OPTIONS_DATA.widgetReplacementExceptions.includes(key);
+    const isSelected = OPTIONS_DATA.settings.widgetReplacementExceptions.includes(key);
     const option = new Option(key, key, false, isSelected);
     widgetSelector.append(option).trigger("change");
   });
@@ -177,7 +235,10 @@ function loadOptions() {
   reloadDisabledSites();
   reloadTrackingDomainsTab();
 
-  $('html').css('visibility', 'visible');
+  $('html').css({
+    overflow: 'visible',
+    visibility: 'visible'
+  });
 
   window.OPTIONS_INITIALIZED = true;
 }
@@ -248,7 +309,7 @@ function parseUserDataFile(storageMapsList) {
     type: "mergeUserData",
     data: lists
   }, (response) => {
-    OPTIONS_DATA.disabledSites = response.disabledSites;
+    OPTIONS_DATA.settings.disabledSites = response.disabledSites;
     OPTIONS_DATA.origins = response.origins;
 
     reloadDisabledSites();
@@ -283,7 +344,7 @@ function downloadCloud() {
     function (response) {
       if (response.success) {
         alert(i18n.getMessage("download_cloud_success"));
-        OPTIONS_DATA.disabledSites = response.disabledSites;
+        OPTIONS_DATA.settings.disabledSites = response.disabledSites;
         reloadDisabledSites();
       } else {
         console.error("Cloud sync error:", response.message);
@@ -451,17 +512,8 @@ function updateCheckingDNTPolicy() {
   });
 }
 
-function updateLearnInIncognito() {
-  const learnInIncognito = $("#learn-in-incognito-checkbox").prop("checked");
-
-  chrome.runtime.sendMessage({
-    type: "updateSettings",
-    data: { learnInIncognito }
-  });
-}
-
 function reloadDisabledSites() {
-  let sites = OPTIONS_DATA.disabledSites,
+  let sites = OPTIONS_DATA.settings.disabledSites,
     $select = $('#allowlist-select');
 
   // sort disabled sites the same way blocked sites are sorted
@@ -488,7 +540,7 @@ function addDisabledSite(event) {
     type: "disablePrivacyBadgerForOrigin",
     domain
   }, (response) => {
-    OPTIONS_DATA.disabledSites = response.disabledSites;
+    OPTIONS_DATA.settings.disabledSites = response.disabledSites;
     reloadDisabledSites();
     document.getElementById("new-disabled-site-input").value = "";
   });
@@ -507,7 +559,7 @@ function removeDisabledSite(event) {
     type: "enablePrivacyBadgerForOriginList",
     domains
   }, (response) => {
-    OPTIONS_DATA.disabledSites = response.disabledSites;
+    OPTIONS_DATA.settings.disabledSites = response.disabledSites;
     reloadDisabledSites();
   });
 }
@@ -542,13 +594,11 @@ function revertDomainControl(event) {
  * Displays list of all tracking domains along with toggle controls.
  */
 function updateSummary() {
-  // Check to see if any tracking domains have been found before continuing.
-  let allTrackingDomains = getOriginsArray(OPTIONS_DATA.origins, null, null, null, true);
-
+  // if there are no tracking domains
+  let allTrackingDomains = Object.keys(OPTIONS_DATA.origins);
   if (!allTrackingDomains || !allTrackingDomains.length) {
-    // leave out number of trackers and slider instructions message if no sliders will be displayed
+    // hide the number of trackers and slider instructions message
     $("#options_domain_list_trackers").hide();
-    $("#options_domain_list_one_tracker").hide();
 
     // show "no trackers" message
     $("#options_domain_list_no_trackers").show();
@@ -565,23 +615,15 @@ function updateSummary() {
   $("#options_domain_list_no_trackers").hide();
   $("#tracking-domains-div").show();
 
-  let baseDomains = new Set(allTrackingDomains.map(d => window.getBaseDomain(d)));
-
-  // Update messages according to tracking domain count.
-  if (baseDomains.size == 1) {
-    // leave out messages about multiple trackers
-    $("#options_domain_list_trackers").hide();
-
-    // show singular "tracker" message
-    $("#options_domain_list_one_tracker").show();
-  } else {
-    $("#options_domain_list_trackers").html(i18n.getMessage(
-      "options_domain_list_trackers", [
-        baseDomains.size,
-        "<a target='_blank' title='" + _.escape(i18n.getMessage("what_is_a_tracker")) + "' class='tooltip' href='https://privacybadger.org/#What-is-a-third-party-tracker'>"
-      ]
-    )).show();
-  }
+  // count unique (cookie)blocked tracking base domains
+  let blockedDomains = getOriginsArray(OPTIONS_DATA.origins, null, null, null, false);
+  let baseDomains = new Set(blockedDomains.map(d => window.getBaseDomain(d)));
+  $("#options_domain_list_trackers").html(i18n.getMessage(
+    "options_domain_list_trackers", [
+      baseDomains.size,
+      "<a target='_blank' title='" + _.escape(i18n.getMessage("what_is_a_tracker")) + "' class='tooltip' href='https://privacybadger.org/#What-is-a-third-party-tracker'>"
+    ]
+  )).show();
 }
 
 /**
@@ -612,8 +654,9 @@ function reloadTrackingDomainsTab() {
  * Displays filtered list of tracking domains based on user input.
  */
 function filterTrackingDomains() {
-  const $typeFilter = $('#tracking-domains-type-filter');
-  const $statusFilter = $('#tracking-domains-status-filter');
+  const $searchFilter = $('#trackingDomainSearch'),
+    $typeFilter = $('#tracking-domains-type-filter'),
+    $statusFilter = $('#tracking-domains-status-filter');
 
   if ($typeFilter.val() == "dnt") {
     $statusFilter.prop("disabled", true).val("");
@@ -621,93 +664,102 @@ function filterTrackingDomains() {
     $statusFilter.prop("disabled", false);
   }
 
-  var initialSearchText = $('#trackingDomainSearch').val().toLowerCase();
+  let search_update = (this == $searchFilter[0]),
+    initial_search_text = $searchFilter.val().toLowerCase(),
+    time_to_wait = 0,
+    callback = function () {};
 
-  // Wait a short period of time and see if search text has changed.
+  // If we are here because the search filter got updated,
+  // wait a short period of time and see if search text has changed.
   // If so it means user is still typing so hold off on filtering.
-  var timeToWait = 500;
-  setTimeout(function() {
-    // Check search text.
-    var searchText = $('#trackingDomainSearch').val().toLowerCase();
-    if (searchText !== initialSearchText) {
+  if (search_update) {
+    time_to_wait = 500;
+    callback = function () {
+      $searchFilter.focus();
+    };
+  }
+
+  setTimeout(function () {
+    // check search text
+    let search_text = $searchFilter.val().toLowerCase();
+    if (search_text != initial_search_text) {
       return;
     }
 
-    // Show filtered origins.
-    var filteredOrigins = getOriginsArray(
+    // show filtered origins
+    let filteredOrigins = getOriginsArray(
       OPTIONS_DATA.origins,
-      searchText,
+      search_text,
       $typeFilter.val(),
       $statusFilter.val(),
       $('#tracking-domains-show-not-yet-blocked').prop('checked')
     );
-    showTrackingDomains(filteredOrigins);
-  }, timeToWait);
+    showTrackingDomains(filteredOrigins, callback);
+
+  }, time_to_wait);
 }
 
 /**
- * Adds more origins to the blocked resources list on scroll.
+ * Renders the list of tracking domains.
  *
-*/
-function addOrigins(e) {
-  let domains = e.data;
-  if (!domains.length) {
-    return;
-  }
-
-  let el = e.target;
-  let total_height = el.scrollHeight - el.clientHeight;
-  if ((total_height - el.scrollTop) >= 400) {
-    return;
-  }
-
-  for (let i = 0; (i < 50) && (domains.length > 0); i++) {
-    let domain = domains.shift();
-    let action = getOriginAction(domain);
-    if (action) {
-      let show_breakage_warning = (
-        action == constants.USER_BLOCK &&
-        OPTIONS_DATA.cookieblocked.hasOwnProperty(domain)
-      );
-      $(el).append(htmlUtils.getOriginHtml(domain, action, show_breakage_warning));
-    }
-  }
-
-  // activate tooltips
-  $('#blockedResourcesInner .tooltip:not(.tooltipstered)').tooltipster(
-    htmlUtils.DOMAIN_TOOLTIP_CONF);
-}
-
-/**
- * Displays list of tracking domains along with toggle controls.
- * @param {Array} domains Tracking domains to display.
+ * @param {Array} domains
+ * @param {Function} cb callback
  */
-function showTrackingDomains(domains) {
+function showTrackingDomains(domains, cb) {
+  if (!cb) {
+    cb = function () {};
+  }
+
+  window.SLIDERS_DONE = false;
+  $('#tracking-domains-div').css('visibility', 'hidden');
+  $('#tracking-domains-loader').show();
+
   domains = htmlUtils.sortDomains(domains);
 
-  // Create HTML for the initial list of tracking domains.
-  let out = '';
-  for (let i = 0; (i < 50) && (domains.length > 0); i++) {
-    let domain = domains.shift();
+  let out = [];
+  for (let domain of domains) {
     let action = getOriginAction(domain);
     if (action) {
       let show_breakage_warning = (
         action == constants.USER_BLOCK &&
         OPTIONS_DATA.cookieblocked.hasOwnProperty(domain)
       );
-      out += htmlUtils.getOriginHtml(domain, action, show_breakage_warning);
+      out.push(htmlUtils.getOriginHtml(domain, action, show_breakage_warning));
     }
   }
 
-  // Display tracking domains.
-  $('#blockedResourcesInner').html(out);
+  function renderDomains() {
+    const CHUNK = 100;
 
-  $('#blockedResourcesInner').off("scroll");
-  $('#blockedResourcesInner').on("scroll", domains, addOrigins);
+    let $printable = $(out.splice(0, CHUNK).join(""));
 
-  // activate tooltips
-  $('#blockedResourcesInner .tooltip:not(.tooltipstered)').tooltipster(
-    htmlUtils.DOMAIN_TOOLTIP_CONF);
+    $printable.appendTo('#blockedResourcesInner');
+
+    // activate tooltips
+    // TODO disabled for performance reasons
+    //$('#blockedResourcesInner .tooltip:not(.tooltipstered)').tooltipster(
+    //  htmlUtils.DOMAIN_TOOLTIP_CONF);
+
+    if (out.length) {
+      requestAnimationFrame(renderDomains);
+    } else {
+      $('#tracking-domains-loader').hide();
+      $('#tracking-domains-div').css('visibility', 'visible');
+      window.SLIDERS_DONE = true;
+      cb();
+    }
+  }
+
+  $('#blockedResourcesInner').empty();
+
+  if (out.length) {
+    requestAnimationFrame(renderDomains);
+  } else {
+    $('#tracking-domains-loader').hide();
+    $('#tracking-domains-div').css('visibility', 'visible');
+    window.SLIDERS_DONE = true;
+    cb();
+  }
 }
 
 /**
@@ -737,6 +789,50 @@ function toggleWebRTCIPProtection() {
   });
 }
 
+// handles overriding the alternateErrorPagesEnabled setting
+function overrideAlternateErrorPagesSetting() {
+  const checked = $("#disable-google-nav-error-service-checkbox").prop("checked");
+
+  // update Badger settings so that we know to reapply the browser setting on startup
+  chrome.runtime.sendMessage({
+    type: "updateSettings",
+    data: {
+      disableGoogleNavErrorService: checked
+    }
+  });
+
+  // update the browser setting
+  if (checked) {
+    chrome.privacy.services.alternateErrorPagesEnabled.set({
+      value: false
+    });
+  } else {
+    chrome.privacy.services.alternateErrorPagesEnabled.clear({});
+  }
+}
+
+// handles overriding the hyperlinkAuditingEnabled setting
+function overrideHyperlinkAuditingSetting() {
+  const checked = $("#disable-hyperlink-auditing-checkbox").prop("checked");
+
+  // update Badger settings so that we know to reapply the browser setting on startup
+  chrome.runtime.sendMessage({
+    type: "updateSettings",
+    data: {
+      disableHyperlinkAuditing: checked
+    }
+  });
+
+  // update the browser setting
+  if (checked) {
+    chrome.privacy.websites.hyperlinkAuditingEnabled.set({
+      value: false
+    });
+  } else {
+    chrome.privacy.websites.hyperlinkAuditingEnabled.clear({});
+  }
+}
+
 /**
  * Updates domain tooltip, slider color.
  * Also toggles status indicators like breakage warnings.
@@ -760,10 +856,11 @@ function updateOrigin(origin, action, userset) {
   htmlUtils.toggleBlockedStatus($clicker, userset, show_breakage_warning);
 
   // reinitialize the domain tooltip
-  $clicker.find('.origin-inner').tooltipster('destroy');
-  $clicker.find('.origin-inner').attr(
-    'title', htmlUtils.getActionDescription(action, origin));
-  $clicker.find('.origin-inner').tooltipster(htmlUtils.DOMAIN_TOOLTIP_CONF);
+  // TODO disabled for performance reasons
+  //$clicker.find('.origin-inner').tooltipster('destroy');
+  //$clicker.find('.origin-inner').attr(
+  //  'title', htmlUtils.getActionDescription(action, origin));
+  //$clicker.find('.origin-inner').tooltipster(htmlUtils.DOMAIN_TOOLTIP_CONF);
 }
 
 /**
