@@ -29,10 +29,12 @@ QUnit.module("tabData", {
 function() {
   QUnit.module("logThirdPartyOriginOnTab", {
     beforeEach: function () {
+      this.clock = sinon.useFakeTimers();
       sinon.stub(chrome.browserAction, "setBadgeText");
     },
     afterEach: function () {
       chrome.browserAction.setBadgeText.restore();
+      this.clock.restore();
     },
   });
 
@@ -48,6 +50,7 @@ function() {
 
     // log blocked domain
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.BLOCK);
+    this.clock.tick(1);
     assert.equal(
       badger.getTrackerCount(this.tabId), 1, "count gets incremented"
     );
@@ -63,21 +66,19 @@ function() {
 
   QUnit.test("logging unblocked domain", function (assert) {
     badger.logThirdPartyOriginOnTab(this.tabId, "example.com", constants.ALLOW);
+    this.clock.tick(1);
     assert.equal(
-      badger.getTrackerCount(this.tabId), 1, "count gets incremented"
+      badger.getTrackerCount(this.tabId), 0, "count stays at zero"
     );
     assert.ok(
-      chrome.browserAction.setBadgeText.calledOnce,
-      "updateBadge gets called when we see an unblocked domain"
+      chrome.browserAction.setBadgeText.notCalled,
+      "updateBadge does not get called when we see a hasn't-decided-yet-to-block domain"
     );
-    assert.ok(chrome.browserAction.setBadgeText.calledWithExactly({
-      tabId: this.tabId,
-      text: "1"
-    }), "setBadgeText was called with expected args");
   });
 
   QUnit.test("logging DNT-compliant domain", function (assert) {
     badger.logThirdPartyOriginOnTab(this.tabId, "example.com", constants.DNT);
+    this.clock.tick(1);
     assert.equal(
       badger.getTrackerCount(this.tabId), 0, "count stays at zero"
     );
@@ -92,17 +93,20 @@ function() {
 
     // log unblocked domain
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.ALLOW);
+    this.clock.tick(1);
 
     // set up domain blocking (used by getTrackerCount)
     badger.storage.setupHeuristicAction(DOMAIN, constants.BLOCK);
 
     // log the same domain, this time as blocked
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.BLOCK);
+    this.clock.tick(1);
     assert.equal(
       badger.getTrackerCount(this.tabId), 1, "count gets incremented"
     );
-    assert.ok(
-      chrome.browserAction.setBadgeText.calledOnce,
+    assert.equal(
+      chrome.browserAction.setBadgeText.callCount,
+      "1",
       "updateBadge gets called when we see a blocked domain"
     );
     assert.ok(chrome.browserAction.setBadgeText.calledWithExactly({
@@ -119,6 +123,7 @@ function() {
 
     // log blocked domain
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.BLOCK);
+    this.clock.tick(1);
     assert.equal(
       badger.getTrackerCount(this.tabId), 1, "count gets incremented"
     );
@@ -133,6 +138,7 @@ function() {
 
     // log the same blocked domain again
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.BLOCK);
+    this.clock.tick(1);
     assert.equal(
       badger.getTrackerCount(this.tabId),
       1,
@@ -149,13 +155,16 @@ function() {
 
     // log unblocked domain twice
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.ALLOW);
+    this.clock.tick(1);
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.ALLOW);
+    this.clock.tick(1);
 
     // set up domain blocking (used by getTrackerCount)
     badger.storage.setupHeuristicAction(DOMAIN, constants.BLOCK);
 
     // log blocked domain
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.BLOCK);
+    this.clock.tick(1);
     assert.equal(
       badger.getTrackerCount(this.tabId), 1, "count gets incremented"
     );
@@ -170,6 +179,7 @@ function() {
 
     // log the same blocked domain again
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.BLOCK);
+    this.clock.tick(1);
     assert.equal(
       badger.getTrackerCount(this.tabId),
       1,
@@ -189,6 +199,7 @@ function() {
 
     // log cookieblocked domain
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.COOKIEBLOCK);
+    this.clock.tick(1);
     assert.equal(
       badger.getTrackerCount(this.tabId), 1, "count gets incremented"
     );
@@ -212,6 +223,7 @@ function() {
 
     // log blocked domain
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN1, constants.BLOCK);
+    this.clock.tick(1);
     assert.equal(
       badger.getTrackerCount(this.tabId), 1, "count gets incremented"
     );
@@ -226,6 +238,7 @@ function() {
 
     // log cookieblocked domain
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN2, constants.COOKIEBLOCK);
+    this.clock.tick(1);
     assert.equal(
       badger.getTrackerCount(this.tabId), 2, "count gets incremented again"
     );
