@@ -7,13 +7,6 @@ import pbtest
 
 
 class ClobberingTest(pbtest.PBSeleniumTest):
-    COOKIEBLOCK_JS = (
-        "(function (domain) {"
-        "  let bg = chrome.extension.getBackgroundPage();"
-        "  bg.badger.storage.setupHeuristicAction(domain, bg.constants.COOKIEBLOCK);"
-        "}(arguments[0]));"
-    )
-
     def test_localstorage_clobbering(self):
         LOCALSTORAGE_TESTS = [
             # (test result element ID, expected stored, expected empty)
@@ -27,11 +20,8 @@ class ClobberingTest(pbtest.PBSeleniumTest):
         ]
         # page loads a frame that writes to and reads from localStorage
         # TODO remove delays from fixture once race condition (https://crbug.com/478183) is fixed
-        FIXTURE_URL = (
-            "https://efforg.github.io/privacybadger-test-fixtures/html/"
-            "clobbering.html"
-        )
-        FRAME_DOMAIN = "githack.com"
+        FIXTURE_URL = "https://privacybadger-tests.eff.org/html/clobbering.html"
+        FRAME_DOMAIN = "efforg.github.io"
 
         # first allow localStorage to be set
         self.load_url(FIXTURE_URL)
@@ -55,8 +45,7 @@ class ClobberingTest(pbtest.PBSeleniumTest):
             )
 
         # mark the frame domain for cookieblocking
-        self.load_url(self.options_url)
-        self.js(self.COOKIEBLOCK_JS, FRAME_DOMAIN)
+        self.cookieblock_domain(FRAME_DOMAIN)
 
         # now rerun and check results for various localStorage access tests
         self.load_url(FIXTURE_URL)
@@ -100,8 +89,7 @@ class ClobberingTest(pbtest.PBSeleniumTest):
         )
 
         # cookieblock the domain fetched by the fixture
-        self.load_url(self.options_url)
-        self.js(self.COOKIEBLOCK_JS, THIRD_PARTY_DOMAIN)
+        self.cookieblock_domain(THIRD_PARTY_DOMAIN)
 
         # recheck what the referrer header looks like now after cookieblocking
         verify_referrer_header(
@@ -109,5 +97,6 @@ class ClobberingTest(pbtest.PBSeleniumTest):
             "Referrer header does not appear to be origin-only"
         )
 
+
 if __name__ == "__main__":
     unittest.main()
