@@ -11,7 +11,6 @@ from functools import partial
 from selenium.common.exceptions import NoSuchElementException
 
 from pbtest import retry_until
-from window_utils import switch_to_window_with_url
 
 
 class DntTest(pbtest.PBSeleniumTest):
@@ -77,7 +76,7 @@ class DntTest(pbtest.PBSeleniumTest):
         )
 
     @pbtest.repeat_if_failed(3)
-    def test_dnt_check_should_happen_for_blocked_domains(self):
+    def test_dnt_policy_check_should_happen_for_blocked_domains(self):
         PAGE_URL = (
             "https://efforg.github.io/privacybadger-test-fixtures/html/"
             "dnt.html"
@@ -92,7 +91,7 @@ class DntTest(pbtest.PBSeleniumTest):
         self.load_url(PAGE_URL)
 
         # switch back to Badger's options page
-        switch_to_window_with_url(self.driver, self.options_url)
+        self.switch_to_window_with_url(self.options_url)
 
         # verify that the domain is blocked
         self.assertTrue(self.domain_was_detected(DNT_DOMAIN),
@@ -102,13 +101,13 @@ class DntTest(pbtest.PBSeleniumTest):
 
         def reload_and_see_if_unblocked():
             # switch back to the page with the DNT-compliant resource
-            switch_to_window_with_url(self.driver, PAGE_URL)
+            self.switch_to_window_with_url(PAGE_URL)
 
             # reload it
             self.load_url(PAGE_URL)
 
             # switch back to Badger's options page
-            switch_to_window_with_url(self.driver, self.options_url)
+            self.switch_to_window_with_url(self.options_url)
 
             return (
                 self.domain_was_detected(DNT_DOMAIN) and
@@ -124,7 +123,7 @@ class DntTest(pbtest.PBSeleniumTest):
         self.assertFalse(was_blocked,
             msg="DNT-compliant resource should have gotten unblocked.")
 
-    def test_dnt_check_should_not_set_cookies(self):
+    def test_dnt_policy_check_should_not_set_cookies(self):
         TEST_DOMAIN = "dnt-test.trackersimulator.org"
         TEST_URL = "https://{}/".format(TEST_DOMAIN)
 
@@ -160,7 +159,7 @@ class DntTest(pbtest.PBSeleniumTest):
         self.assertEqual(len(self.driver.get_cookies()), 0,
             "Shouldn't have any cookies after the DNT check")
 
-    def test_dnt_check_should_not_send_cookies(self):
+    def test_dnt_policy_check_should_not_send_cookies(self):
         TEST_DOMAIN = "dnt-request-cookies-test.trackersimulator.org"
         TEST_URL = "https://{}/".format(TEST_DOMAIN)
 
@@ -201,6 +200,10 @@ class DntTest(pbtest.PBSeleniumTest):
         self.load_url(self.options_url)
         self.js("chrome.extension.getBackgroundPage().badger.storage.clearTrackerData();")
 
+        # enable local learning
+        self.wait_for_script("return window.OPTIONS_INITIALIZED")
+        self.find_el_by_css('#local-learning-checkbox').click()
+
         # visit a page containing two third-party resources,
         # one from a cookie-tracking domain
         # and one from a non-tracking domain
@@ -236,18 +239,35 @@ class DntTest(pbtest.PBSeleniumTest):
         TEST_URL = "https://httpbin.org/get"
         headers = retry_until(partial(self.get_first_party_headers, TEST_URL),
                               times=8)
-        self.assertTrue(headers is not None, "It seems we failed to get DNT headers")
+        self.assertTrue(headers is not None, "It seems we failed to get headers")
         self.assertIn('Dnt', headers, "DNT header should have been present")
+        self.assertIn('Sec-Gpc', headers, "GPC header should have been present")
         self.assertEqual(headers['Dnt'], "1",
             'DNT header should have been set to "1"')
+        self.assertEqual(headers['Sec-Gpc'], "1",
+            'Sec-Gpc header should have been set to "1"')
 
-    def test_no_dnt_header_when_disabled(self):
+    def test_no_dnt_header_when_disabled_on_site(self):
         TEST_URL = "https://httpbin.org/get"
         self.disable_badger_on_site(TEST_URL)
         headers = retry_until(partial(self.get_first_party_headers, TEST_URL),
                               times=8)
-        self.assertTrue(headers is not None, "It seems we failed to get DNT headers")
+        self.assertTrue(headers is not None, "It seems we failed to get headers")
         self.assertNotIn('Dnt', headers, "DNT header should have been missing")
+        self.assertNotIn('Sec-Gpc', headers, "GPC header should have been missing")
+
+    def test_no_dnt_header_when_dnt_disabled(self):
+        TEST_URL = "https://httpbin.org/get"
+
+        self.load_url(self.options_url)
+        self.wait_for_script("return window.OPTIONS_INITIALIZED")
+        self.find_el_by_css('#enable_dnt_checkbox').click()
+
+        headers = retry_until(partial(self.get_first_party_headers, TEST_URL),
+                              times=8)
+        self.assertTrue(headers is not None, "It seems we failed to get headers")
+        self.assertNotIn('Dnt', headers, "DNT header should have been missing")
+        self.assertNotIn('Sec-Gpc', headers, "GPC header should have been missing")
 
     def test_navigator_object(self):
         self.load_url(DntTest.NAVIGATOR_DNT_TEST_URL, wait_for_body_text=True)
@@ -257,8 +277,13 @@ class DntTest(pbtest.PBSeleniumTest):
             'no tracking (navigator.doNotTrack="1")',
             "navigator.DoNotTrack should have been set to \"1\""
         )
+        self.assertEqual(
+            self.js("return navigator.globalPrivacyControl"),
+            "1",
+            "navigator.globalPrivacyControl should have been set to \"1\""
+        )
 
-    def test_navigator_left_alone_when_disabled(self):
+    def test_navigator_unmodified_when_disabled_on_site(self):
         self.disable_badger_on_site(DntTest.NAVIGATOR_DNT_TEST_URL)
 
         self.load_url(DntTest.NAVIGATOR_DNT_TEST_URL, wait_for_body_text=True)
@@ -269,6 +294,30 @@ class DntTest(pbtest.PBSeleniumTest):
             'unset',
             "navigator.DoNotTrack should have been left unset"
         )
+        self.assertEqual(
+            self.js("return navigator.globalPrivacyControl"),
+            None,
+            "navigator.globalPrivacyControl should have been left unset"
+        )
+
+    def test_navigator_unmodified_when_dnt_disabled(self):
+        self.load_url(self.options_url)
+        self.wait_for_script("return window.OPTIONS_INITIALIZED")
+        self.find_el_by_css('#enable_dnt_checkbox').click()
+
+        self.load_url(DntTest.NAVIGATOR_DNT_TEST_URL, wait_for_body_text=True)
+
+        # navigator.doNotTrack defaults to null in Chrome, "unspecified" in Firefox
+        self.assertEqual(
+            self.driver.find_element_by_tag_name('body').text[0:5],
+            'unset',
+            "navigator.DoNotTrack should have been left unset"
+        )
+        self.assertEqual(
+            self.js("return navigator.globalPrivacyControl"),
+            None,
+            "navigator.globalPrivacyControl should have been left unset"
+        )
 
 
 if __name__ == "__main__":
