@@ -6,8 +6,6 @@ import unittest
 
 import pbtest
 
-from random import randint
-
 from selenium.common.exceptions import (
     ElementNotInteractableException,
     ElementNotVisibleException,
@@ -19,8 +17,6 @@ from selenium.webdriver.common.by import By
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.support.ui import WebDriverWait
 
-from window_utils import switch_to_window_with_url
-
 
 class OptionsTest(pbtest.PBSeleniumTest):
     """Make sure the options page works correctly."""
@@ -62,11 +58,9 @@ class OptionsTest(pbtest.PBSeleniumTest):
     def select_manage_data_tab(self):
         self.find_el_by_css('a[href="#tab-manage-data"]').click()
 
-    def check_tracker_messages(self, error_message, many, one, none):
+    def check_tracker_messages(self, error_message, many, none):
         self.assertEqual(many,
             self.driver.find_element_by_id("options_domain_list_trackers").is_displayed(), error_message)
-        self.assertEqual(one,
-            self.driver.find_element_by_id("options_domain_list_one_tracker").is_displayed(), error_message)
         self.assertEqual(none,
             self.driver.find_element_by_id("options_domain_list_no_trackers").is_displayed(), error_message)
 
@@ -87,15 +81,6 @@ class OptionsTest(pbtest.PBSeleniumTest):
             ".badger.storage.setupHeuristicAction('{}', '{}');"
         ).format(origin, action))
 
-    def add_test_origins(self, origins_with_actions):
-        """Add a dictionary of origins with their actions to backend storage."""
-        self.load_options_page()
-        for origin in origins_with_actions:
-            self.js((
-                "chrome.extension.getBackgroundPage()"
-                ".badger.storage.setupHeuristicAction('{}', '{}');"
-            ).format(origin, origins_with_actions[origin]))
-
     def user_overwrite(self, origin, action):
         # Get the slider that corresponds to this radio button
         origin_div = self.find_el_by_css('div[data-origin="' + origin + '"]')
@@ -115,16 +100,6 @@ class OptionsTest(pbtest.PBSeleniumTest):
         click_action.click()
         click_action.perform()
 
-    def scroll_to_bottom(self):
-        # Scroll far enough to generate one new element in the tracking domains box
-        self.driver.execute_script("window.scrollTo(0, document.body.scrollHeight);")
-        scrollable_div = self.driver.find_element_by_id('blockedResourcesInner')
-        self.driver.execute_script("arguments[0].scrollTop = arguments[0].scrollHeight", scrollable_div)
-
-    def scroll_to_origin(self, origin):
-        generated_element = self.find_el_by_css("div[data-origin='" + origin + "']")
-        self.driver.execute_script("return arguments[0].scrollIntoView(true);", generated_element)
-
     def test_page_title(self):
         self.load_options_page()
         localized_title = self.js('return chrome.i18n.getMessage("options_title")')
@@ -145,8 +120,8 @@ class OptionsTest(pbtest.PBSeleniumTest):
         self.load_options_page()
         self.select_domain_list_tab()
 
-        error_message = "Only the 'one tracker' message should be displayed after adding an origin"
-        self.check_tracker_messages(error_message, many=False, one=True, none=False)
+        error_message = "The 'multiple tracker' message should be displayed after adding an origin"
+        self.check_tracker_messages(error_message, many=True, none=False)
 
         try:
             self.find_origin_by_xpath("pbtest.org")
@@ -163,13 +138,13 @@ class OptionsTest(pbtest.PBSeleniumTest):
         self.load_options_page()
         self.select_domain_list_tab()
 
-        error_message = "Only the 'multiple tracker' messages should be displayed after adding 2 origins"
-        self.check_tracker_messages(error_message, many=True, one=False, none=False)
+        error_message = "The 'multiple tracker' message should be displayed after adding 2 origins"
+        self.check_tracker_messages(error_message, many=True, none=False)
 
         # check tracker count
         self.assertEqual(
             self.driver.find_element_by_id("options_domain_list_trackers").text,
-            "Privacy Badger has detected 2 potential tracking domains so far.",
+            "Privacy Badger has decided to block 2 potential tracking domains so far",
             "Origin tracker count should be 2 after adding origin"
         )
 
@@ -207,9 +182,8 @@ class OptionsTest(pbtest.PBSeleniumTest):
 
         error_message = "Only the 'no trackers' message should be displayed before adding an origin"
         self.assertFalse(
-            self.driver.find_element_by_id("options_domain_list_one_tracker").is_displayed(), error_message)
-        self.assertFalse(
-            self.driver.find_element_by_id("options_domain_list_trackers").is_displayed(), error_message)
+            self.driver.find_element_by_id(
+                "options_domain_list_trackers").is_displayed(), error_message)
 
         # Check that no origins are displayed.
         try:
@@ -225,7 +199,7 @@ class OptionsTest(pbtest.PBSeleniumTest):
 
         # make sure the default tracker list includes many trackers
         error_message = "By default, the tracker list should contain many trackers"
-        self.check_tracker_messages(error_message, many=True, one=False, none=False)
+        self.check_tracker_messages(error_message, many=True, none=False)
 
         # get the number of trackers in the seed data
         default_summary_text = self.driver.find_element_by_id("options_domain_list_trackers").text
@@ -240,7 +214,7 @@ class OptionsTest(pbtest.PBSeleniumTest):
         # now make sure the tracker list is empty
         self.select_domain_list_tab()
         error_message = "No trackers should be displayed after removing all data"
-        self.check_tracker_messages(error_message, many=False, one=False, none=True)
+        self.check_tracker_messages(error_message, many=False, none=True)
 
         # add new blocked domains
         self.add_test_origin("pbtest.org", "block")
@@ -253,7 +227,7 @@ class OptionsTest(pbtest.PBSeleniumTest):
         # make sure only two trackers are displayed now
         self.assertEqual(
             self.driver.find_element_by_id("options_domain_list_trackers").text,
-            "Privacy Badger has detected 2 potential tracking domains so far.",
+            "Privacy Badger has decided to block 2 potential tracking domains so far",
             "Origin tracker count should be 2 after clearing and adding origins"
         )
 
@@ -276,9 +250,13 @@ class OptionsTest(pbtest.PBSeleniumTest):
         self.add_test_origin("pbtest.org", original_action)
 
         self.load_options_page()
+        self.wait_for_script("return window.OPTIONS_INITIALIZED")
+        # enable learning to reveal the show-not-yet-blocked checkbox
+        self.find_el_by_css('#local-learning-checkbox').click()
         self.select_domain_list_tab()
-        if original_action == "allow":
-            self.find_el_by_css('#tracking-domains-show-not-yet-blocked').click()
+        self.find_el_by_css('#tracking-domains-show-not-yet-blocked').click()
+        # wait for sliders to finish rendering
+        self.wait_for_script("return window.SLIDERS_DONE")
 
         # Change user preferences
         self.user_overwrite("pbtest.org", overwrite_action)
@@ -286,6 +264,9 @@ class OptionsTest(pbtest.PBSeleniumTest):
         # Re-open the tab
         self.load_options_page()
         self.select_domain_list_tab()
+        self.find_el_by_css('#tracking-domains-show-not-yet-blocked').click()
+        # wait for sliders to finish rendering
+        self.wait_for_script("return window.SLIDERS_DONE")
 
         # Check the user preferences for the origins are still displayed
         failure_msg = (
@@ -312,71 +293,6 @@ class OptionsTest(pbtest.PBSeleniumTest):
     def test_tracking_user_overwrite_blocked_cookieblock(self):
         self.tracking_user_overwrite('block', 'cookieblock')
 
-    def test_tracking_user_overwrite_on_scroll(self):
-        # Create a bunch of origins with random actions
-        origins = {}
-        actions = ['allow', 'cookieblock', 'block']
-        for i in range (0, 50):
-            name = ""
-            if i<10: name = 'pbtest0' + str(i) + '.org'
-            else:
-                name = 'pbtest' + str(i) + '.org'
-
-            origins[name] = actions[randint(0,2)]
-        # Add an origin to be generated on scroll (once there are 50 already)
-        origins['pbtest50-generated.org'] = 'allow'
-
-        self.clear_seed_data()
-        self.add_test_origins(origins)
-
-        self.load_options_page()
-        self.select_domain_list_tab()
-        self.find_el_by_css('#tracking-domains-show-not-yet-blocked').click()
-        time.sleep(1) # wait for domains to rerender
-
-        # Scroll until the first generated origin is added to the html
-        self.scroll_to_bottom()
-        self.scroll_to_bottom()
-
-        # Set a different action for it. First ensure it's been scrolled into view
-        self.scroll_to_origin('pbtest50-generated.org')
-        self.user_overwrite("pbtest50-generated.org", 'block')
-
-        # The page should have refreshed, scroll once to generate the element and again to the very bottom
-        self.scroll_to_bottom()
-        self.scroll_to_bottom()
-
-        try:
-            WebDriverWait(self.driver, 3).until(
-                EC.presence_of_element_located(
-                    (By.XPATH, '//div[@data-origin="pbtest50-generated.org"]')))
-        except TimeoutException:
-            self.fail("Timed out waiting for element generated on scroll")
-
-        failure_msg = (
-            "Scroll-generated origin should be displayed as blocked "
-            "after user overwrite of PB's decision to allow"
-        )
-        self.assert_slider_state("pbtest50-generated.org", "block", failure_msg)
-
-        ## Check that changes have been persisted
-
-        # Re-open the tab
-        self.load_options_page()
-        self.select_domain_list_tab()
-        self.find_el_by_css('#tracking-domains-show-not-yet-blocked').click()
-        time.sleep(1) # wait for domains to rerender
-        self.scroll_to_bottom()
-        self.scroll_to_bottom()
-        self.scroll_to_origin('pbtest50-generated.org')
-
-        # Check the user preferences for the origins are still displayed
-        failure_msg = (
-            "Scroll-generated origin should be persisted as blocked "
-            "after user overwrite of PB's decision to allow"
-        )
-        self.assert_slider_state("pbtest50-generated.org", "block", failure_msg)
-
     # early-warning check for the open_in_tab attribute of options_ui
     # https://github.com/EFForg/privacybadger/pull/1775#pullrequestreview-76940251
     def test_options_ui_open_in_tab(self):
@@ -385,7 +301,7 @@ class OptionsTest(pbtest.PBSeleniumTest):
         self.load_options_page()
 
         # switch to new user intro page
-        switch_to_window_with_url(self.driver, self.first_run_url)
+        self.switch_to_window_with_url(self.first_run_url)
 
         # save open windows
         handles_before = set(self.driver.window_handles)
