@@ -12,13 +12,22 @@ from functools import wraps
 from shutil import copytree
 
 from selenium import webdriver
-from selenium.common.exceptions import TimeoutException, WebDriverException
+from selenium.common.exceptions import (
+    NoSuchWindowException,
+    TimeoutException,
+    WebDriverException,
+)
 from selenium.webdriver.chrome.options import Options as ChromeOptions
 from selenium.webdriver.firefox.options import Options as FirefoxOptions
 from selenium.webdriver.support.ui import WebDriverWait
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.common.by import By
-from xvfbwrapper import Xvfb
+
+try:
+    from xvfbwrapper import Xvfb
+except ImportError:
+    print("\n\nxvfbwrapper Python package import failed")
+    print("headless mode (ENABLE_XVFB=1) is not supported")
 
 
 SEL_DEFAULT_WAIT_TIMEOUT = 30
@@ -33,6 +42,10 @@ run_shell_command = lambda command: parse_stdout(subprocess.check_output(command
 GIT_ROOT = run_shell_command(['git', 'rev-parse', '--show-toplevel'])
 
 
+class WindowNotFoundException(Exception):
+    pass
+
+
 def unix_which(command, silent=False):
     try:
         return run_shell_command(['which', command])
@@ -44,7 +57,7 @@ def unix_which(command, silent=False):
 
 def get_browser_type(string):
     for t in BROWSER_TYPES:
-        if t in string:
+        if t in string.lower():
             return t
     raise ValueError("couldn't get browser type from %s" % string)
 
@@ -138,6 +151,11 @@ class Shim:
     @property
     def wants_xvfb(self):
         if self.on_travis or bool(int(os.environ.get('ENABLE_XVFB', 0))):
+            try:
+                Xvfb
+            except NameError:
+                print("\nHeadless mode not supported: install xvfbwrapper first")
+                return False
             return True
         return False
 
@@ -185,6 +203,9 @@ class Shim:
         for i in range(5):
             try:
                 opts = FirefoxOptions()
+                # to produce a trace-level geckodriver.log,
+                # remove the service_log_path argument to Firefox()
+                # and uncomment the line below
                 #opts.log.level = "trace"
                 driver = webdriver.Firefox(
                     firefox_profile=ffp,
@@ -288,7 +309,6 @@ class PBSeleniumTest(unittest.TestCase):
             cls.vdisplay.stop()
 
     def init(self, driver):
-        self._logs = []
         self.driver = driver
         self.js = self.driver.execute_script
         self.bg_url = self.base_url + "_generated_background_page.html"
@@ -310,6 +330,7 @@ class PBSeleniumTest(unittest.TestCase):
                         "return chrome.extension.getBackgroundPage()."
                         "badger.INITIALIZED"
                     )
+
                     driver.close()
                     if driver.window_handles:
                         driver.switch_to.window(driver.window_handles[0])
@@ -415,6 +436,36 @@ class PBSeleniumTest(unittest.TestCase):
             EC.frame_to_be_available_and_switch_to_it(
                 (By.CSS_SELECTOR, selector)))
 
+    def switch_to_window_with_url(self, url, max_tries=5):
+        """Point the driver to the first window that matches this url."""
+
+        for _ in range(max_tries):
+            for w in self.driver.window_handles:
+                try:
+                    self.driver.switch_to.window(w)
+                    if self.driver.current_url != url:
+                        continue
+                except NoSuchWindowException:
+                    pass
+                else:
+                    return
+
+            time.sleep(1)
+
+        raise WindowNotFoundException("Failed to find window for " + url)
+
+
+    def close_window_with_url(self, url, max_tries=5):
+        self.switch_to_window_with_url(url, max_tries)
+
+        if len(self.driver.window_handles) == 1:
+            # open another window to avoid implicit session deletion
+            self.open_window()
+            self.switch_to_window_with_url(url, max_tries)
+
+        self.driver.close()
+        self.driver.switch_to.window(self.driver.window_handles[0])
+
     def block_domain(self, domain):
         self.load_url(self.options_url)
         self.js((
@@ -443,7 +494,5 @@ class PBSeleniumTest(unittest.TestCase):
 
     @property
     def logs(self):
-        def strip(l):
-            return l.split('/')[-1]
-        self._logs.extend([strip(l.get('message')) for l in self.driver.get_log('browser')])
-        return self._logs
+        # TODO not yet in Firefox
+        return [log.get('message') for log in self.driver.get_log('browser')]
